#################################################
#Obtaining the time-tree
#All files can be found at GitHub repository: https://figshare.com/s/6b42cf2d4d0cadde7e11
#We mainly used the strap (Bell & Lloyd 2014) for obtaining a time tree and
#################################################
library(paleotree)
library(strap)

#Load the 'ages' file with first (FAD) and last appearances (LAD)
metacryphaeus.ages <- read.table("metacryphaeus-ages.txt", header = T)

#Load the ultrametric tree (in nexus format)
metacryphaeus.ultra.tree <- read.nexus("metacryphaeus-ultra-tree.nex")

#Check the tree
plot(metacryphaeus.ultra.tree)

#Time scale the ultrametric tree 
metacryphaeus.timetree <- timePaleoPhy(metacryphaeus.ultra.tree, metacryphaeus.ages, type="mbl", vartime = 1)
plot(metacryphaeus.timetree)

#check the age of the root
metacryphaeus.timetree$root.time

#export timetree as nexus
write.nexus(metacryphaeus.timetree, file="timetree.nex")
write.tree(metacryphaeus.timetree, file = "timetree.newick")

#export it as PDF with stratigraphic time scale
#first, plot and check details
geoscalePhylo(ladderize(metacryphaeus.timetree, right=FALSE), metacryphaeus.ages, cex.ts=0.5)
#now export the PDF file
pdf("metacryphaeus-time-tree.pdf", width=10, height=7)
geoscalePhylo(ladderize(metacryphaeus.timetree, right=FALSE), metacryphaeus.ages, cex.ts=0.5)
dev.off()